@@ -1,7 +1,8 @@
 import sqlite3
 
-from .mlog import start, get
-from .mlog import MLOG_DB, SQL_CREATE_RUNS_TABLE, SQL_CREATE_LOGS_TABLE
+from .mlog import start, get, lst, delete
+from .mlog import MLOG_DIR, MLOG_DB
+from .mlog import SQL_CREATE_RUNS_TABLE, SQL_CREATE_LOGS_TABLE
 
 
 MLOG_DIR.mkdir(parents=True, exist_ok=True)
